@@ -133,6 +133,11 @@ where
 /// - [`UnescapedReservedCharacter`].
 /// - [`UnfinishedParameter`].
 ///
+/// # Indexing
+///
+/// The given `indexer` is incremented only if the parsed [`Parameter`] is
+/// returned.
+///
 /// [`Error`]: Err::Error
 /// [`Failure`]: Err::Failure
 /// [`EscapedNonReservedCharacter`]: Error::EscapedNonReservedCharacter
@@ -143,6 +148,7 @@ where
 /// [0]: crate#grammar
 pub fn parameter<'a, Input: 'a>(
     input: Input,
+    indexer: &mut usize,
 ) -> IResult<Input, Parameter<Input>, Error<Input>>
 where
     Input: Clone
@@ -164,13 +170,15 @@ where
         match inp.iter_elements().next().map(AsChar::as_char) {
             Some('{') => {
                 if let Ok((_, (par, ..))) = peek(tuple((
-                    parameter,
+                    // We don't use `indexer` here, because we do this parsing
+                    // for error reporting only.
+                    |i| parameter(i, &mut 0),
                     escaped_reserved_chars0(take_while(is_name)),
                     tag("}"),
                 )))(inp.clone())
                 {
                     return Error::NestedParameter(
-                        inp.take(par.0.input_len() + 2),
+                        inp.take(par.input.input_len() + 2),
                     )
                     .failure();
                 }
@@ -203,7 +211,14 @@ where
         fail(input.clone(), opening_brace.clone())
     })(input.clone())?;
 
-    Ok((input, Parameter(par_name)))
+    *indexer += 1;
+    Ok((
+        input,
+        Parameter {
+            input: par_name,
+            id: *indexer - 1,
+        },
+    ))
 }
 
 /// Parses an `optional` as defined in the [grammar spec][0].
@@ -291,9 +306,13 @@ where
                     .failure();
             }
             Some('{') => {
-                if let Ok((_, par)) = peek(parameter)(inp.clone()) {
+                // We use just `0` as `indexer` here, because we do this parsing
+                // for error reporting only.
+                if let Ok((_, par)) =
+                    peek(|i| parameter(i, &mut 0))(inp.clone())
+                {
                     return Error::ParameterInOptional(
-                        inp.take(par.0.input_len() + 2),
+                        inp.take(par.input.input_len() + 2),
                     )
                     .failure();
                 }
@@ -503,10 +522,16 @@ where
 ///
 /// Any [`Failure`] of [`alternation()`], [`optional()`] or [`parameter()`].
 ///
+/// # Indexing
+///
+/// The given `indexer` is incremented only if the parsed [`SingleExpression`]
+/// is returned and it represents a [`Parameter`].
+///
 /// [`Failure`]: Err::Failure
 /// [0]: crate#grammar
 pub fn single_expression<'a, Input: 'a>(
     input: Input,
+    indexer: &mut usize,
 ) -> IResult<Input, SingleExpression<Input>, Error<Input>>
 where
     Input: Clone
@@ -528,7 +553,7 @@ where
     alt((
         map(alternation, SingleExpression::Alternation),
         map(optional, SingleExpression::Optional),
-        map(parameter, SingleExpression::Parameter),
+        map(|i| parameter(i, indexer), SingleExpression::Parameter),
         map(
             verify(
                 escaped_reserved_chars0(take_while(is_without_whitespace)),
@@ -584,7 +609,11 @@ where
     Error<Input>: ParseError<Input>,
     for<'s> &'s str: FindToken<<Input as InputIter>::Item>,
 {
-    map(many0(single_expression), Expression)(input)
+    let mut indexer = 0;
+    map(
+        many0(move |i| single_expression(i, &mut indexer)),
+        Expression,
+    )(input)
 }
 
 /// Possible parsing errors.
@@ -731,6 +760,7 @@ where
     Other(#[error(not(source))] Input, ErrorKind),
 
     /// Parsing requires more data.
+    // TODO: Use "{n}" syntax once MSRV bumps above 1.58.
     #[display(
         fmt = "{}",
         "match _0 {\
@@ -783,6 +813,7 @@ mod spec {
     /// [AST]: https://en.wikipedia.org/wiki/Abstract_syntax_tree
     fn assert_ast_eq(actual: impl fmt::Debug, expected: impl AsRef<str>) {
         assert_eq!(
+            // TODO: Use "{actual:#?}" syntax once MSRV bumps above 1.58.
             format!("{:#?}", actual)
                 .lines()
                 .map(|line| line.trim_start().trim_end_matches('\n'))
@@ -799,6 +830,7 @@ mod spec {
     fn unwrap_parser<'s, T>(
         parser: IResult<Spanned<'s>, T, Error<Spanned<'s>>>,
     ) -> T {
+        // TODO: Use "{e}" syntax once MSRV bumps above 1.58.
         let (rest, par) =
             parser.unwrap_or_else(|e| panic!("Expected Ok, found Err: {}", e));
         assert_eq!(*rest, "");
@@ -810,13 +842,16 @@ mod spec {
 
         #[test]
         fn empty() {
-            assert_eq!(**unwrap_parser(parameter(Spanned::new("{}"))), "");
+            assert_eq!(
+                **unwrap_parser(parameter(Spanned::new("{}"), &mut 0)),
+                "",
+            );
         }
 
         #[test]
         fn named() {
             assert_eq!(
-                **unwrap_parser(parameter(Spanned::new("{string}"))),
+                **unwrap_parser(parameter(Spanned::new("{string}"), &mut 0)),
                 "string",
             );
         }
@@ -824,7 +859,10 @@ mod spec {
         #[test]
         fn named_with_spaces() {
             assert_eq!(
-                **unwrap_parser(parameter(Spanned::new("{with space}"))),
+                **unwrap_parser(parameter(
+                    Spanned::new("{with space}"),
+                    &mut 0,
+                )),
                 "with space",
             );
         }
@@ -832,7 +870,7 @@ mod spec {
         #[test]
         fn named_with_escaped() {
             assert_eq!(
-                **unwrap_parser(parameter(Spanned::new("{with \\{}"))),
+                **unwrap_parser(parameter(Spanned::new("{with \\{}"), &mut 0)),
                 "with \\{",
             );
         }
@@ -840,15 +878,17 @@ mod spec {
         #[test]
         fn named_with_closing_paren() {
             assert_eq!(
-                **unwrap_parser(parameter(Spanned::new("{with )}"))),
+                **unwrap_parser(parameter(Spanned::new("{with )}"), &mut 0)),
                 "with )",
             );
         }
 
-        #[allow(clippy::non_ascii_literal)]
         #[test]
         fn named_with_emoji() {
-            assert_eq!(**unwrap_parser(parameter(Spanned::new("{🦀}"))), "🦀");
+            assert_eq!(
+                **unwrap_parser(parameter(Spanned::new("{🦀}"), &mut 0)),
+                "🦀",
+            );
         }
 
         #[test]
@@ -856,20 +896,21 @@ mod spec {
             let span = Spanned::new("");
 
             assert_eq!(
-                parameter(span),
+                parameter(span, &mut 0),
                 Err(Err::Error(Error::Other(span, ErrorKind::Tag))),
             );
         }
 
         #[test]
         fn fails_on_escaped_non_reserved() {
-            let err = parameter(Spanned::new("{\\r}")).unwrap_err();
+            let err = parameter(Spanned::new("{\\r}"), &mut 0).unwrap_err();
 
             match err {
                 Err::Failure(Error::EscapedNonReservedCharacter(e)) => {
                     assert_eq!(*e, "\\r");
                 }
                 Err::Incomplete(_) | Err::Error(_) | Err::Failure(_) => {
+                    // TODO: Use "{err:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", err);
                 }
             }
@@ -883,10 +924,14 @@ mod spec {
                 "{{nest}after}",
                 "{bef{nest}aft}",
             ] {
-                match parameter(Spanned::new(input)).expect_err("error") {
+                match parameter(Spanned::new(input), &mut 0).expect_err("error")
+                {
                     Err::Failure(Error::NestedParameter(e)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*e, "{nest}", "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -900,10 +945,14 @@ mod spec {
                 "{(nest)after}",
                 "{bef(nest)aft}",
             ] {
-                match parameter(Spanned::new(input)).expect_err("error") {
+                match parameter(Spanned::new(input), &mut 0).expect_err("error")
+                {
                     Err::Failure(Error::OptionalInParameter(e)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*e, "(nest)", "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -917,10 +966,14 @@ mod spec {
                 ("{{nest}", "{"),
                 ("{l/r}", "/"),
             ] {
-                match parameter(Spanned::new(input)).expect_err("error") {
+                match parameter(Spanned::new(input), &mut 0).expect_err("error")
+                {
                     Err::Failure(Error::UnescapedReservedCharacter(e)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*e, expected, "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -929,10 +982,14 @@ mod spec {
         #[test]
         fn fails_on_unfinished() {
             for input in ["{", "{name "] {
-                match parameter(Spanned::new(input)).expect_err("error") {
+                match parameter(Spanned::new(input), &mut 0).expect_err("error")
+                {
                     Err::Failure(Error::UnfinishedParameter(e)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*e, "{", "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -974,7 +1031,6 @@ mod spec {
             );
         }
 
-        #[allow(clippy::non_ascii_literal)]
         #[test]
         fn with_emoji() {
             assert_eq!(**unwrap_parser(optional(Spanned::new("(🦀)"))), "🦀");
@@ -999,6 +1055,7 @@ mod spec {
                     assert_eq!(*e, "()");
                 }
                 Err::Incomplete(_) | Err::Error(_) | Err::Failure(_) => {
+                    // TODO: Use "{err:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", err)
                 }
             }
@@ -1028,8 +1085,11 @@ mod spec {
             ] {
                 match optional(Spanned::new(input)).expect_err("error") {
                     Err::Failure(Error::NestedOptional(e)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*e, "(nest)", "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -1045,8 +1105,11 @@ mod spec {
             ] {
                 match optional(Spanned::new(input)).expect_err("error") {
                     Err::Failure(Error::ParameterInOptional(e)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*e, "{nest}", "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -1057,8 +1120,11 @@ mod spec {
             for input in ["(/)", "(bef/)", "(/aft)", "(bef/aft)"] {
                 match optional(Spanned::new(input)).expect_err("error") {
                     Err::Failure(Error::AlternationInOptional(e)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*e, "/", "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -1071,8 +1137,11 @@ mod spec {
             {
                 match optional(Spanned::new(input)).expect_err("error") {
                     Err::Failure(Error::UnescapedReservedCharacter(e)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*e, expected, "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -1083,8 +1152,11 @@ mod spec {
             for input in ["(", "(name "] {
                 match optional(Spanned::new(input)).expect_err("error") {
                     Err::Failure(Error::UnfinishedOptional(e)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*e, "(", "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -1097,12 +1169,13 @@ mod spec {
             Spanned,
         };
 
-        #[allow(clippy::non_ascii_literal)]
         #[test]
         fn text() {
             for input in ["string", "🦀"] {
                 match unwrap_parser(alternative(Spanned::new(input))) {
                     Alternative::Text(t) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*t, input, "on input: {}", input);
                     }
                     _ => panic!("expected Alternative::Text"),
@@ -1115,6 +1188,8 @@ mod spec {
             for input in ["bef\\ ", "\\ aft", "bef\\ aft"] {
                 match unwrap_parser(alternative(Spanned::new(input))) {
                     Alternative::Text(t) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*t, input, "on input: {}", input);
                     }
                     _ => panic!("expected Alternative::Text"),
@@ -1156,6 +1231,7 @@ mod spec {
             match alternative(Spanned::new("")).unwrap_err() {
                 Err::Error(Error::Other(_, ErrorKind::Alt)) => {}
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", e);
                 }
             }
@@ -1166,8 +1242,11 @@ mod spec {
             for input in ["(", "(opt"] {
                 match alternative(Spanned::new(input)).unwrap_err() {
                     Err::Failure(Error::UnfinishedOptional(e)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*e, "(", "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -1178,8 +1257,11 @@ mod spec {
             for input in ["(\\r)", "\\r"] {
                 match alternative(Spanned::new(input)).unwrap_err() {
                     Err::Failure(Error::EscapedNonReservedCharacter(e)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*e, "\\r", "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -1192,7 +1274,6 @@ mod spec {
             Spanned,
         };
 
-        #[allow(clippy::non_ascii_literal)]
         #[test]
         fn basic() {
             assert_ast_eq(
@@ -1418,8 +1499,11 @@ mod spec {
             ] {
                 match alternation(Spanned::new(input)).unwrap_err() {
                     Err::Error(Error::Other(_, kind)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(kind, expected, "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -1430,8 +1514,11 @@ mod spec {
             for input in ["/", "l/", "/r", "l/m/", "l//r", "/m/r"] {
                 match alternation(Spanned::new(input)).unwrap_err() {
                     Err::Failure(Error::EmptyAlternation(e)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*e, "/", "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -1444,8 +1531,11 @@ mod spec {
             {
                 match alternation(Spanned::new(input)).unwrap_err() {
                     Err::Failure(Error::OnlyOptionalInAlternation(e)) => {
+                        // TODO: Use "{input}" syntax once MSRV bumps above
+                        //       1.58.
                         assert_eq!(*e, input, "on input: {}", input);
                     }
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     e => panic!("wrong error: {:?}", e),
                 }
             }
@@ -1459,6 +1549,47 @@ mod spec {
             assert_ast_eq, expression, unwrap_parser, Err, Error, Spanned,
         };
 
+        #[test]
+        fn parameters_ids() {
+            assert_ast_eq(
+                unwrap_parser(expression(Spanned::new("{string} {string}"))),
+                r#"Expression(
+                    [
+                        Parameter(
+                            Parameter {
+                                input: LocatedSpan {
+                                    offset: 1,
+                                    line: 1,
+                                    fragment: "string",
+                                    extra: (),
+                                },
+                                id: 0,
+                            },
+                        ),
+                        Whitespaces(
+                            LocatedSpan {
+                                offset: 8,
+                                line: 1,
+                                fragment: " ",
+                                extra: (),
+                            },
+                        ),
+                        Parameter(
+                            Parameter {
+                                input: LocatedSpan {
+                                    offset: 10,
+                                    line: 1,
+                                    fragment: "string",
+                                    extra: (),
+                                },
+                                id: 1,
+                            },
+                        ),
+                    ],
+                )"#,
+            )
+        }
+
         #[test]
         fn allows_escaped_optional_parameter_types() {
             assert_ast_eq(
@@ -1474,14 +1605,15 @@ mod spec {
                             },
                         ),
                         Parameter(
-                            Parameter(
-                                LocatedSpan {
+                            Parameter {
+                                input: LocatedSpan {
                                     offset: 3,
                                     line: 1,
                                     fragment: "int",
                                     extra: (),
                                 },
-                            ),
+                                id: 0,
+                            },
                         ),
                         Text(
                             LocatedSpan {
@@ -1529,14 +1661,15 @@ mod spec {
                             ),
                         ),
                         Parameter(
-                            Parameter(
-                                LocatedSpan {
+                            Parameter {
+                                input: LocatedSpan {
                                     offset: 4,
                                     line: 1,
                                     fragment: "int",
                                     extra: (),
                                 },
-                            ),
+                                id: 0,
+                            },
                         ),
                         Alternation(
                             Alternation(
@@ -1576,14 +1709,15 @@ mod spec {
                 r#"Expression(
                     [
                         Parameter(
-                            Parameter(
-                                LocatedSpan {
+                            Parameter {
+                                input: LocatedSpan {
                                     offset: 1,
                                     line: 1,
                                     fragment: "int",
                                     extra: (),
                                 },
-                            ),
+                                id: 0,
+                            },
                         ),
                         Alternation(
                             Alternation(
@@ -1645,6 +1779,7 @@ mod spec {
                     assert_eq!(*s, "/");
                 }
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", e);
                 }
             }
@@ -1659,6 +1794,7 @@ mod spec {
                     assert_eq!(*s, "/");
                 }
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", e);
                 }
             }
@@ -1675,6 +1811,7 @@ mod spec {
                     assert_eq!(*s, "(brown)/black");
                 }
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", e);
                 }
             }
@@ -1689,6 +1826,7 @@ mod spec {
                     assert_eq!(*s, "/");
                 }
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", e);
                 }
             }
@@ -1703,6 +1841,7 @@ mod spec {
                     assert_eq!(*s, "/");
                 }
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", e);
                 }
             }
@@ -1715,6 +1854,7 @@ mod spec {
                     assert_eq!(*s, "()");
                 }
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", e);
                 }
             }
@@ -1727,6 +1867,7 @@ mod spec {
                     assert_eq!(*s, "(b)");
                 }
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", e);
                 }
             }
@@ -1739,6 +1880,7 @@ mod spec {
                     assert_eq!(*s, "{int}");
                 }
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", e);
                 }
             }
@@ -1751,6 +1893,7 @@ mod spec {
                     assert_eq!(*s, "(string)");
                 }
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", e);
                 }
             }
@@ -1767,6 +1910,7 @@ mod spec {
                     assert_eq!(*s, "{");
                 }
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", e);
                 }
             }
@@ -1783,6 +1927,7 @@ mod spec {
                     assert_eq!(*s, "{string}");
                 }
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", e);
                 }
             }
@@ -1799,6 +1944,7 @@ mod spec {
                     assert_eq!(*s, "(");
                 }
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{e:?}" syntax once MSRV bumps above 1.58.
                     panic!("wrong error: {:?}", e);
                 }
             }
@@ -1882,14 +2028,15 @@ mod spec {
                 r#"Expression(
                     [
                         Parameter(
-                            Parameter(
-                                LocatedSpan {
+                            Parameter {
+                                input: LocatedSpan {
                                     offset: 1,
                                     line: 1,
                                     fragment: "",
                                     extra: (),
                                 },
-                            ),
+                                id: 0,
+                            },
                         ),
                     ],
                 )"#,
@@ -2076,14 +2223,15 @@ mod spec {
                 r#"Expression(
                     [
                         Parameter(
-                            Parameter(
-                                LocatedSpan {
+                            Parameter {
+                                input: LocatedSpan {
                                     offset: 1,
                                     line: 1,
                                     fragment: "int",
                                     extra: (),
                                 },
-                            ),
+                                id: 0,
+                            },
                         ),
                         Whitespaces(
                             LocatedSpan {
@@ -2149,6 +2297,7 @@ mod spec {
             match expression(Spanned::new("\\")).unwrap_err() {
                 Err::Failure(Error::EscapedEndOfLine(_)) => {}
                 e @ (Err::Incomplete(_) | Err::Error(_) | Err::Failure(_)) => {
+                    // TODO: Use "{err}" syntax once MSRV bumps above 1.58.
                     panic!("wrong err: {}", e);
                 }
             }
